@@ -1,10 +1,9 @@
 import os
-import uuid
 import boto3
 import logging
 import botocore
+import tempfile
 from pathlib import Path
-from urllib.parse import unquote_plus
 
 # declare the logging object
 logger = logging.getLogger()
@@ -15,6 +14,7 @@ logger.debug(f"path: {path}")
 
 
 def sqs_delete_message(receipt_handle):
+    """deletes a message from the SQS queue"""
     logger.debug(f"sqs_delete_message('{receipt_handle}') called")
 
     s = boto3.session.Session()
@@ -25,7 +25,9 @@ def sqs_delete_message(receipt_handle):
 
     # delete the message that has been processed
     try:
-        c.delete_message(QueueUrl=os.environ["SQS_QUEUE_URL"], ReceiptHandle=receipt_handle)
+        c.delete_message(
+            QueueUrl=os.environ["SQS_QUEUE_URL"], ReceiptHandle=receipt_handle
+        )
     except botocore.exceptions.ClientError as e:
         if e.response["Error"]["Code"] == "AWS.SimpleQueueService.NonExistentQueue":
             logger.error(f"The queue {os.environ['SQS_QUEUE_URL']} does not exist")
@@ -36,12 +38,13 @@ def sqs_delete_message(receipt_handle):
 
 
 def sqs_send_message(body):
-    logger.debug(f'send_sqs_message("body") called')
+    """sends a message to the SQS queue"""
+    logger.debug('send_sqs_message("body") called')
 
     # establich a boto3 client for SQS
     s = boto3.session.Session()
     c = s.client("sqs")
-    logger.info(f"boto3 sqs client created")
+    logger.info("boto3 sqs client created")
 
     try:
         # send the message to the SQS Queue
@@ -52,10 +55,11 @@ def sqs_send_message(body):
         else:
             raise e
     else:
-        logger.info(f"sqs message sent")
+        logger.info("sqs message sent")
 
 
 def secrets_manager_get_secret(secret):
+    """gets the secret from the secrets manager"""
     logger.debug(f'secrets_manager_get_secret("{secret}") called')
 
     secret_name = secret
@@ -65,7 +69,7 @@ def secrets_manager_get_secret(secret):
         service_name="secretsmanager",
         region_name=os.environ["AWS_REGION"],
     )
-    logging.info(f"boto3 secretsmanager client created")
+    logging.info("boto3 secretsmanager client created")
 
     try:
         get_secret_value_response = c.get_secret_value(SecretId=secret_name)
@@ -73,35 +77,39 @@ def secrets_manager_get_secret(secret):
         if e.response["Error"]["Code"] == "ResourceNotFoundException":
             logger.error(f"The requested secret {secret_name} was not found")
         elif e.response["Error"]["Code"] == "InvalidRequestException":
-            logger.error("The request was invalid due to:", e)
+            logger.error(f"The request was invalid due to: {e}")
         elif e.response["Error"]["Code"] == "InvalidParameterException":
-            logger.error("The request had invalid params:", e)
+            logger.error(f"The request had invalid params: {e}")
         elif e.response["Error"]["Code"] == "DecryptionFailure":
-            logger.error("The requested secret can't be decrypted using the provided KMS key:", e)
+            logger.error(
+                f"The requested secret can't be decrypted using the provided KMS key: {e}"
+            )
         elif e.response["Error"]["Code"] == "InternalServiceError":
-            logger.error("An error occurred on service side:", e)
+            logger.error(f"An error occurred on service side: {e}")
         else:
             raise e
     else:
         # Secrets Manager decrypts the secret value using the associated KMS CMK
-        # Depending on whether the secret was a string or binary, only one of these fields will be populated
+        # Depending on whether the secret was a string or binary
+        # only one of these fields will be populated
         if "SecretString" in get_secret_value_response:
             text_secret_data = get_secret_value_response["SecretString"]
             return text_secret_data
-        else:
-            binary_secret_data = get_secret_value_response["SecretBinary"]
-            return binary_secret_data
+        binary_secret_data = get_secret_value_response["SecretBinary"]
+        return binary_secret_data
+
+    return None
 
 
 def s3_download(bucket, key):
+    """downloads a file from s3"""
     logger.debug(f's3_download("{bucket}", "{key}") called')
 
     s = boto3.session.Session()
     c = s.resource("s3")
-    logger.info(f"boto3 s3 client created")
+    logger.info("boto3 s3 client created")
 
-    tmpkey = unquote_plus(key).replace("/", "")
-    local_path = f"/tmp/{uuid.uuid4()}{tmpkey}"
+    local_path = tempfile.TemporaryFile()
 
     try:
         c.Bucket(bucket).download_file(key, local_path)
@@ -114,13 +122,16 @@ def s3_download(bucket, key):
         logger.info(f"{key} downloaded to {local_path}")
         return local_path
 
+    return None
+
 
 def s3_upload(bucket, key, local_path):
+    """uploads a file to s3"""
     logger.debug(f's3_upload("{bucket}", "{key}", "{local_path}") called')
 
     s = boto3.session.Session()
     c = s.resource("s3")
-    logger.info(f"boto3 s3 client created")
+    logger.info("boto3 s3 client created")
 
     try:
         c.Bucket(bucket).upload_file(local_path, key)
